OmegaAgentMessage class

Direct message from one agent (from) to another (to).

Sent with OmegaAgentProtocol.send. The receiver gets it in OmegaAgent.receiveMessage, which enqueues it in OmegaAgentInbox and calls OmegaAgent.onMessage.

Constructors

OmegaAgentMessage({required String from, required String to, required String action, dynamic payload})
const

Properties

action String
Action or command (e.g. "invalidateToken", "validate").
final
from String
Sender agent id (or "system" for OmegaAgentProtocol.broadcast).
final
hashCode int
The hash code for this object.
no setterinherited
payload → dynamic
Optional data for the action.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
to String
Receiver agent id. Must match a registered agent id for OmegaAgentProtocol.send to deliver.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited