register method
Registers an agent. Called at bootstrap for each agent in the config. If an agent with the same agent.id exists, it is replaced.
Implementation
void register(OmegaAgent agent) {
agents[agent.id] = agent;
}
Registers an agent. Called at bootstrap for each agent in the config. If an agent with the same agent.id exists, it is replaced.
void register(OmegaAgent agent) {
agents[agent.id] = agent;
}