initialFlowId property
Id of the flow to activate when the app opens. The host calls flowManager.switchTo(initialFlowId) on the first frame.
Implementation
final String? initialFlowId;
Id of the flow to activate when the app opens. The host calls flowManager.switchTo(initialFlowId) on the first frame.
final String? initialFlowId;