namespace property
Optional namespace (e.g. "auth", "checkout"). Can be used by the host to route to the right module.
Implementation
final String? namespace;
Optional namespace (e.g. "auth", "checkout"). Can be used by the host to route to the right module.
final String? namespace;