registerFlow method
Registers a flow so it can be activated and receive intents. Call at bootstrap (omega_setup).
Example: flowManager.registerFlow(AuthFlow(channel));
Implementation
void registerFlow(OmegaFlow flow) {
_flows[flow.id] = flow;
}
Registers a flow so it can be activated and receive intents. Call at bootstrap (omega_setup).
Example: flowManager.registerFlow(AuthFlow(channel));
void registerFlow(OmegaFlow flow) {
_flows[flow.id] = flow;
}