OmegaScope class

Dependency container: exposes channel and flowManager to the whole UI via inheritance.

Why use it: Screens need the channel to emit events and the flowManager for handleIntent and getFlow. By wrapping the app with OmegaScope, any child can use OmegaScope.of.

Example: OmegaScope(channel: r.channel, flowManager: r.flowManager, initialFlowId: r.initialFlowId, child: MaterialApp(...));

Inheritance

Constructors

OmegaScope({Key? key, required OmegaChannel channel, required OmegaFlowManager flowManager, String? initialFlowId, required Widget child})
const

Properties

channel OmegaChannel
Event channel. For emitting or listening to events from the UI.
final
child Widget
The widget below this widget in the tree.
finalinherited
flowManager OmegaFlowManager
Flow manager. For handleIntent and getting the active flow (expressions).
final
hashCode int
The hash code for this object.
no setterinherited
initialFlowId String?
Id of the flow to activate on startup. On first frame call flowManager.switchTo(initialFlowId).
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createElement() InheritedElement
Inflates this configuration to a concrete instance.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited
updateShouldNotify(covariant OmegaScope oldWidget) bool
Whether the framework should notify widgets that inherit from this widget.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

of(BuildContext context) OmegaScope
Obtains the OmegaScope from the tree. Use in screens to access channel and flowManager.